import { Player, ItemComponentTypes, ItemStack, system, EquipmentSlot, GameMode, world, EntityInventoryComponent, EntityEquippableComponent, HudElement, HudVisibility } from "@minecraft/server";
import {
  ActionFormData,
  MessageFormData,
  ModalFormData
} from '@minecraft/server-ui';

let playerPosition = world.getDynamicProperty("playerPosition") || 0;

const mapaNuevoSpawn = [
    ["TagJugador", "NuevoSpawn", "VistaAlFrente", "QuitarBloque1", "QuitarBloque2", "NuevaCamPos", "QuitarGlass1", "QuitarGlass2", "QuitarGlass3", "QuitarGlass4"],
    ["ReadyPlayer_1", "11.50 -299.00 -5.50", "11 -299 -5", "11 -299 -6", "11 -298 -6", "13 -297 -4", "11 -299 -5", "11 -297 -5", "10 -298 -5", "12 -298 -5"],
    ["ReadyPlayer_2", "11.50 -299.00 6.50", "11 -299 -7", "11 -299 6", "11 -298 6", "13 -297 3", "11 -299 5", "11 -297 5", "10 -298 5", "12 -298 5"],
    ["ReadyPlayer_3", "5.50 -299.00 -5.50", "5 -299 -5", "5 -299 -6", "5 -298 -6", "7 -297 -4", "5 -299 -5", "5 -297 -5", "4 -298 -5", "6 -298 -5"],
    ["ReadyPlayer_4", "5.50 -299.00 6.50", "5 -299 -7", "5 -299 6", "5 -298 6", "7 -297 3", "5 -299 5", "5 -297 5", "4 -298 5", "6 -298 5"],
    ["ReadyPlayer_5", "-1.50 -299.00 -5.50", "-1 -299 -5", "-1 -299 -6", "-1 -298 -6", "1 -297 -4", "-1 -299 -5", "-1 -297 -5", "-2 -298 -5", "0 -298 -5"],
    ["ReadyPlayer_6", "-1.50 -299.00 6.50", "-1 -299 -7", "-1 -299 6", "-1 -298 6", "1 -297 3", "-1 -299 5", "-1 -297 5", "-2 -298 5", "0 -298 5"],
    ["ReadyPlayer_7", "-7.50 -299.00 -7.50", "-7 -299 -5", "-7 -299 -6", "-7 -298 -6", "-5 -297 -4", "-7 -299 -5", "-7 -297 -5", "-8 -298 -5", "-6 -298 -5"],
    ["ReadyPlayer_8", "-7.50 -299.00 6.50", "-7 -299 -7", "-7 -299 6", "-7 -298 6", "-5 -297 3", "-7 -299 5", "-7 -297 5", "-8 -298 5", "-6 -298 5"],
    ["ReadyPlayer_9", "-13.50 -299.00 -7.50", "-13 -299 -5", "-13 -299 -6", "-13 -298 -6", "-11 -297 -4", "-13 -299 -5", "-13 -297 -5", "-14 -298 -5", "-12 -298 -5"],
    ["ReadyPlayer_10", "-13.50 -299.00 6.50", "-13 -299 -7", "-13 -299 6", "-13 -298 6", "-11 -297 3", "-13 -299 5", "-13 -297 5", "-14 -298 5", "-12 -298 5"]
];

const playerArmaduras = [
    ["oldtech:robot_blue_core", "oldtech:ot_robotpart_blue","oldtech:robot_helmet_blue","oldtech:robot_chestplate_blue","oldtech:robot_leggings_blue","oldtech:robot_boots_blue"],
    ["oldtech:robot_brown_core", "oldtech:ot_robotpart_brown","oldtech:robot_helmet_brown","oldtech:robot_chestplate_brown","oldtech:robot_leggings_brown","oldtech:robot_boots_brown"],
    ["oldtech:robot_cyan_core", "oldtech:ot_robotpart_cyan","oldtech:robot_helmet_cyan","oldtech:robot_chestplate_cyan","oldtech:robot_leggings_cyan","oldtech:robot_boots_cyan"],
    ["oldtech:robot_green_core", "oldtech:ot_robotpart_green","oldtech:robot_helmet_green","oldtech:robot_chestplate_green","oldtech:robot_leggings_green","oldtech:robot_boots_green"],
    ["oldtech:robot_light_blue_core", "oldtech:ot_robotpart_light_blue","oldtech:robot_helmet_light_blue","oldtech:robot_chestplate_light_blue","oldtech:robot_leggings_light_blue","oldtech:robot_boots_light_blue"],
    ["oldtech:robot_lime_core", "oldtech:ot_robotpart_lime","oldtech:robot_helmet_lime","oldtech:robot_chestplate_lime","oldtech:robot_leggings_lime","oldtech:robot_boots_lime"],
    ["oldtech:robot_magenta_core", "oldtech:ot_robotpart_magenta","oldtech:robot_helmet_magenta","oldtech:robot_chestplate_magenta","oldtech:robot_leggings_magenta","oldtech:robot_boots_magenta"],
    ["oldtech:robot_orange_core", "oldtech:ot_robotpart_orange","oldtech:robot_helmet_orange","oldtech:robot_chestplate_orange","oldtech:robot_leggings_orange","oldtech:robot_boots_orange"],
    ["oldtech:robot_pink_core", "oldtech:ot_robotpart_pink","oldtech:robot_helmet_pink","oldtech:robot_chestplate_pink","oldtech:robot_leggings_pink","oldtech:robot_boots_pink"],
    ["oldtech:robot_purple_core", "oldtech:ot_robotpart_purple","oldtech:robot_helmet_purple","oldtech:robot_chestplate_purple","oldtech:robot_leggings_purple","oldtech:robot_boots_purple"],
    ["oldtech:robot_red_core", "oldtech:ot_robotpart_red","oldtech:robot_helmet_red","oldtech:robot_chestplate_red","oldtech:robot_leggings_red","oldtech:robot_boots_red"],
    ["oldtech:robot_white_core", "oldtech:ot_robotpart_white","oldtech:robot_helmet_white","oldtech:robot_chestplate_white","oldtech:robot_leggings_white","oldtech:robot_boots_white"],
    ["oldtech:robot_yellow_core", "oldtech:ot_robotpart_yellow","oldtech:robot_helmet_yellow","oldtech:robot_chestplate_yellow","oldtech:robot_leggings_yellow","oldtech:robot_boots_yellow"]
    ];

world.beforeEvents.worldInitialize.subscribe(({ blockComponentRegistry, itemComponentRegistry }) => {
    blockComponentRegistry.registerCustomComponent(
        "oldtech:ot_robots_botons",
        CustomOT_robots_botons
    );
    blockComponentRegistry.registerCustomComponent(
        "oldtech:ot_robots_door",
        CustomOT_robots_door
    );
    blockComponentRegistry.registerCustomComponent(
        "oldtech:ot_robots_irondoor",
        CustomOT_robots_irondoor
    );
});

const CustomOT_robots_irondoor = {
    
    onPlayerInteract(event) {
    const block = event.block
    const dimension = event.dimension;
    const face = event.face;
    const faceLocation = event.faceLocation;
    const player = event.player;
    
    if (block.matches("oldtech:ot_puerta_iron_door_a")) {
            player.runCommand(`playsound open.iron_door @s ${block.x} ${block.y} ${block.z} 1 1`);
            player.runCommand(`fill ${block.x} ${block.y + 1} ${block.z} ${block.x} ${block.y + 1} ${block.z} oldtech:ot_puerta_iron_door_b ["oldtech:posicion"=1] replace`);
            player.runCommand(`fill ${block.x} ${block.y} ${block.z} ${block.x} ${block.y} ${block.z} oldtech:ot_puerta_iron_door_a ["oldtech:posicion"=1] replace`);
            system.runTimeout(() => {
                player.runCommand(`playsound close.iron_door @s ${block.x} ${block.y} ${block.z} 1 1`);
                player.runCommand(`fill ${block.x} ${block.y + 1} ${block.z} ${block.x} ${block.y + 1} ${block.z} oldtech:ot_puerta_iron_door_b ["oldtech:posicion"=0] replace`);
                player.runCommand(`fill ${block.x} ${block.y} ${block.z} ${block.x} ${block.y} ${block.z} oldtech:ot_puerta_iron_door_a ["oldtech:posicion"=0] replace`);
            }, 30);
        } else if (block.matches("oldtech:ot_puerta_iron_door_b")) {
            player.runCommand(`playsound open.iron_door @s ${block.x} ${block.y} ${block.z} 1 1`);
            player.runCommand(`fill ${block.x} ${block.y - 1} ${block.z} ${block.x} ${block.y - 1} ${block.z} oldtech:ot_puerta_iron_door_a ["oldtech:posicion"=1] replace`);
            player.runCommand(`fill ${block.x} ${block.y} ${block.z} ${block.x} ${block.y} ${block.z} oldtech:ot_puerta_iron_door_b ["oldtech:posicion"=1] replace`);
            system.runTimeout(() => {
                player.runCommand(`playsound close.iron_door @s ${block.x} ${block.y} ${block.z} 1 1`);
                player.runCommand(`fill ${block.x} ${block.y - 1} ${block.z} ${block.x} ${block.y - 1} ${block.z} oldtech:ot_puerta_iron_door_a ["oldtech:posicion"=0] replace`);
                player.runCommand(`fill ${block.x} ${block.y} ${block.z} ${block.x} ${block.y} ${block.z} oldtech:ot_puerta_iron_door_b ["oldtech:posicion"=0] replace`);
            }, 30);
        }
    }
};

const CustomOT_robots_door = {
    
    onPlayerInteract(event) {
    const block = event.block
    const dimension = event.dimension;
    const face = event.face;
    const faceLocation = event.faceLocation;
    const player = event.player;
    
    
    if (!player.hasTag("nuevoSpawn")) {
        playerPosition++;
        world.setDynamicProperty("playerPosition", playerPosition);
        player.addTag("nuevoSpawn");
        player.addTag(`ReadyPlayer_${playerPosition}`);
        
    };
    player.runCommand(`playsound open.iron_door @s ${block.x} ${block.y} ${block.z} 1 1`);
    player.runCommand(`setblock -10 -61 -2 oldtech:ot_puerta_robot_a ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -61 -3 oldtech:ot_puerta_robot_b ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -61 -4 oldtech:ot_puerta_robot_c ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -62 -2 oldtech:ot_puerta_robot_d ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -62 -3 oldtech:ot_puerta_robot_e ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -62 -4 oldtech:ot_puerta_robot_f ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -63 -2 oldtech:ot_puerta_robot_g ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -63 -3 oldtech:ot_puerta_robot_h ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    player.runCommand(`setblock -10 -63 -4 oldtech:ot_puerta_robot_i ["minecraft:cardinal_direction"="east","oldtech:posicion"=1] replace`);
    
    const pecheraArmadura = [
    ["oldtech:robot_blue_core", "oldtech:ot_robotpart_blue","oldtech:robot_helmet_blue","oldtech:robot_chestplate_blue","oldtech:robot_leggings_blue","oldtech:robot_boots_blue"],
    ["oldtech:robot_brown_core", "oldtech:ot_robotpart_brown","oldtech:robot_helmet_brown","oldtech:robot_chestplate_brown","oldtech:robot_leggings_brown","oldtech:robot_boots_brown"],
    ["oldtech:robot_cyan_core", "oldtech:ot_robotpart_cyan","oldtech:robot_helmet_cyan","oldtech:robot_chestplate_cyan","oldtech:robot_leggings_cyan","oldtech:robot_boots_cyan"],
    ["oldtech:robot_green_core", "oldtech:ot_robotpart_green","oldtech:robot_helmet_green","oldtech:robot_chestplate_green","oldtech:robot_leggings_green","oldtech:robot_boots_green"],
    ["oldtech:robot_light_blue_core", "oldtech:ot_robotpart_light_blue","oldtech:robot_helmet_light_blue","oldtech:robot_chestplate_light_blue","oldtech:robot_leggings_light_blue","oldtech:robot_boots_light_blue"],
    ["oldtech:robot_lime_core", "oldtech:ot_robotpart_lime","oldtech:robot_helmet_lime","oldtech:robot_chestplate_lime","oldtech:robot_leggings_lime","oldtech:robot_boots_lime"],
    ["oldtech:robot_magenta_core", "oldtech:ot_robotpart_magenta","oldtech:robot_helmet_magenta","oldtech:robot_chestplate_magenta","oldtech:robot_leggings_magenta","oldtech:robot_boots_magenta"],
    ["oldtech:robot_orange_core", "oldtech:ot_robotpart_orange","oldtech:robot_helmet_orange","oldtech:robot_chestplate_orange","oldtech:robot_leggings_orange","oldtech:robot_boots_orange"],
    ["oldtech:robot_pink_core", "oldtech:ot_robotpart_pink","oldtech:robot_helmet_pink","oldtech:robot_chestplate_pink","oldtech:robot_leggings_pink","oldtech:robot_boots_pink"],
    ["oldtech:robot_purple_core", "oldtech:ot_robotpart_purple","oldtech:robot_helmet_purple","oldtech:robot_chestplate_purple","oldtech:robot_leggings_purple","oldtech:robot_boots_purple"],
    ["oldtech:robot_red_core", "oldtech:ot_robotpart_red","oldtech:robot_helmet_red","oldtech:robot_chestplate_red","oldtech:robot_leggings_red","oldtech:robot_boots_red"],
    ["oldtech:robot_white_core", "oldtech:ot_robotpart_white","oldtech:robot_helmet_white","oldtech:robot_chestplate_white","oldtech:robot_leggings_white","oldtech:robot_boots_white"],
    ["oldtech:robot_yellow_core", "oldtech:ot_robotpart_yellow","oldtech:robot_helmet_yellow","oldtech:robot_chestplate_yellow","oldtech:robot_leggings_yellow","oldtech:robot_boots_yellow"]
    ];
    
    const equippableDoor = player.getComponent("minecraft:equippable");
    const pecherapaArmadura = equippableDoor.getEquipmentSlot(EquipmentSlot.Chest);
    if (!pecherapaArmadura) return;
    
    for (const variableArmor of pecheraArmadura) {

        if (pecherapaArmadura.typeId.includes(variableArmor[0])) {
            player.runCommand(`camera @a[r=50] set minecraft:free pos ^^2^-3 facing ${block.x} ${block.y} ${block.z}`);
            player.runCommand(`summon ${variableArmor[1]} ~~~ facing ${block.x} ${block.y} ${block.z}`);
            const players = world.getPlayers();
            for (const player1 of players) {
                if (!player1.hasTag("OTplayerInGame")) {
                    player1.runCommand(`inputpermission set @s movement disabled`);
                    player1.runCommand(`tp @s ~~~ facing ${block.x} ${block.y} ${block.z}`);
                    system.runTimeout(() => {
                        if (!player1.hasTag("OTplayerInGame")) {
                        player1.runCommand(`inputpermission set @s movement enabled`);
                        player1.runCommand(`camera @s clear`);
                        }
                    }, 50);
                    system.runTimeout(() => {
                        if (player1.hasTag("OTplayerInGame")) {
                        player1.runCommand(`setblock -10 -61 -2 oldtech:ot_puerta_robot_a ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -61 -3 oldtech:ot_puerta_robot_b ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -61 -4 oldtech:ot_puerta_robot_c ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -62 -2 oldtech:ot_puerta_robot_d ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -62 -3 oldtech:ot_puerta_robot_e ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -62 -4 oldtech:ot_puerta_robot_f ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -63 -2 oldtech:ot_puerta_robot_g ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -63 -3 oldtech:ot_puerta_robot_h ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        player1.runCommand(`setblock -10 -63 -4 oldtech:ot_puerta_robot_i ["minecraft:cardinal_direction"="east","oldtech:posicion"=0] replace`);
                        }
                    }, 50);
                }
            }
            player.runCommand(`clear`);
            player.runCommand(`tag @s add OTplayerInGame`);
            player.runCommand(`effect @s resistance 0 0 true`);

            system.runTimeout(() => {
                    player.runCommand(`camera @s fade time 1 1 1`);
                    system.runTimeout(() => {
                        if (player.hasTag("OTplayerInGame")) {
                            player.runCommand(`tp @s ${player.getSpawnPoint().x} ${player.getSpawnPoint().y + 0.5} ${player.getSpawnPoint().z}`);
                            player.runCommand(`camera @s clear`);
                        }
                    }, 30);
            }, 30);
            system.runTimeout(() => {
                if (player.hasTag("OTplayerInGame")) {
                    player.runCommand(`tag @s add ${variableArmor[0]}`);
                    player.runCommand(`replaceitem entity @s slot.armor.head 0 ${variableArmor[2]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                    player.runCommand(`replaceitem entity @s slot.armor.chest 0 ${variableArmor[3]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                    player.runCommand(`replaceitem entity @s slot.armor.legs 0 ${variableArmor[4]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                    player.runCommand(`replaceitem entity @s slot.armor.feet 0 ${variableArmor[5]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                    player.runCommand(`event entity @e[c=1,family=robotpart] despawn`);
                    player.runCommand(`inputpermission set @s movement enabled`);
                    player.runCommand(`camera @s clear`);
                }
            }, 50);
        }
    }
    }
};

const CustomOT_robots_botons = {
    
    onPlayerInteract(event) {
    const block = event.block
    const dimension = event.dimension;
    const face = event.face;
    const faceLocation = event.faceLocation;
    const player = event.player;
    
    const coloresCompleto = [
    ["oldtech:robot_blue_core", "oldtech:ot_robots_botons_blue"],
    ["oldtech:robot_brown_core", "oldtech:ot_robots_botons_brown"],
    ["oldtech:robot_cyan_core", "oldtech:ot_robots_botons_cyan"],
    ["oldtech:robot_green_core", "oldtech:ot_robots_botons_green"],
    ["oldtech:robot_light_blue_core", "oldtech:ot_robots_botons_light_blue"],
    ["oldtech:robot_lime_core", "oldtech:ot_robots_botons_lime"],
    ["oldtech:robot_magenta_core", "oldtech:ot_robots_botons_magenta"],
    ["oldtech:robot_orange_core", "oldtech:ot_robots_botons_orange"],
    ["oldtech:robot_pink_core", "oldtech:ot_robots_botons_pink"],
    ["oldtech:robot_purple_core", "oldtech:ot_robots_botons_purple"],
    ["oldtech:robot_red_core", "oldtech:ot_robots_botons_red"],
    ["oldtech:robot_white_core", "oldtech:ot_robots_botons_white"],
    ["oldtech:robot_yellow_core", "oldtech:ot_robots_botons_yellow"]
    ];

    const equippable = player.getComponent("minecraft:equippable");
    if (!equippable) return;
    const pecheraUsando = equippable.getEquipmentSlot(EquipmentSlot.Chest);
    if (!pecheraUsando) return;
    
    for (const variableColor of coloresCompleto) {

        if (!pecheraUsando.typeId.includes(variableColor[0]) && block.typeId.includes(variableColor[1])) {

            player.runCommand(`setblock ${block.x} ${block.y} ${block.z} ${variableColor[1]} ["minecraft:cardinal_direction"="south","oldtech:posicion"=1] replace`);
            player.runCommand(`replaceitem entity @s slot.armor.chest 0 ${variableColor[0]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
            const playerLocation = player.location;
            player.playSound("dig.cloth", playerLocation);
            player.runCommand(`playsound click_on.wooden_pressure_plate @s ${block.x} ${block.y} ${block.z} 10 1`);

            system.runTimeout(() => {
                player.runCommand(`setblock ${block.x} ${block.y} ${block.z} ${variableColor[1]} ["minecraft:cardinal_direction"="south","oldtech:posicion"=0] replace`);
                player.runCommand(`playsound click_off.wooden_pressure_plate @s ${block.x} ${block.y} ${block.z} 10 1`);
            }, 10);

        }
    }
    }
};

system.runInterval(() => {
    const players = world.getPlayers();
    for (const player of players) {
        for (const variableArmorS of playerArmaduras) {
            if (player.hasTag(`${variableArmorS[0]}`)) {
                player.runCommand(`replaceitem entity @s slot.armor.head 0 ${variableArmorS[2]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                player.runCommand(`replaceitem entity @s slot.armor.chest 0 ${variableArmorS[3]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                player.runCommand(`replaceitem entity @s slot.armor.legs 0 ${variableArmorS[4]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
                player.runCommand(`replaceitem entity @s slot.armor.feet 0 ${variableArmorS[5]} 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
            };
        };
        player.onScreenDisplay.setHudVisibility(HudVisibility.Hide, [HudElement.StatusEffects]);
        player.runCommand("setworldspawn 0 -63 -2");
        player.runCommand("gamerule sendcommandfeedback false");
        player.runCommand(`effect @a[tag=OTplayerInGame] invisibility infinite 1 true`);
        player.runCommand(`effect @a night_vision infinite 1 true`);
        player.runCommand(`gamemode s @a[tag=!OT_RobotAdmin]`);
        player.runCommand(`gamerule showdaysplayed false`);
        player.runCommand(`setmaxplayers 10`);
        player.runCommand(`gamerule showcoordinates false`);
        player.runCommand(`gamerule showtags false`);
    }
}, 5);

world.afterEvents.playerSpawn.subscribe((event) => {
        if (event.player.hasTag("playerJoinRobotTag"))
        return;
        event.player.runCommandAsync("setworldspawn 0 0 0");
        event.player.runCommandAsync(`spreadplayers ~ ~ 5 10 @s`);
        event.player.runCommandAsync(`spawnpoint @s ${event.player.location.x} ${event.player.location.y} ${event.player.location.z}`);
        event.player.runCommandAsync("gamerule sendcommandfeedback false");
        event.player.runCommandAsync("tp @s 0.50 -63.50 -2.50 facing -10.50 -62.50 -2.50");
        system.runTimeout(() => {
            event.player.runCommandAsync("structure load mystructure:spawn_robotlobby -12 -64 -6");
            system.runTimeout(() => {
                event.player.runCommandAsync("tp @s 0.50 -63.50 -2.50");
            }, 10);
        }, 5);
        event.player.runCommandAsync("clear");
        event.player.addTag("playerJoinRobotTag");
        event.player.runCommandAsync(`replaceitem entity @s slot.armor.chest 0 oldtech:robot_white_core 1 0 {"minecraft:keep_on_death":{},"item_lock":{"mode":"lock_in_slot"}}`);
        event.player.runCommandAsync(`effect @s resistance infinite 100 true`);
        formOTRobotSMSinicio(event.player);
});

function formOTRobotSMSinicio(player) {
    const formSistema = new ActionFormData()
        .title('text.title.OTRobotSMSinicioTitle')
        .body({ translate: "text.body1.OTRobotSMSinicioBody1", with: ['\n']})
        .button('text.button.OTRobotSMSinicioButton')

    formSistema.show(player).then((response) => {
        if(response.selection == 0){
            formOTRobotSMSinicio2(player);
        } else if(response.canceled){
            formOTRobotSMSinicio(player);
            }
    });
}
function formOTRobotSMSinicio2(player) {
    const formSistema = new ActionFormData()
        .title('text.title.OTRobotSMSinicioTitle')
        .body({ translate: "text.body1.OTRobotSMSinicioBody2", with: ['\n']})
        .button('text.button.OTRobotSMSinicioButton')

    formSistema.show(player).then((response) => {
        if(response.selection == 0){
            formOTRobotSMSinicio3(player);
        } else if(response.canceled){
            formOTRobotSMSinicio2(player);
            }
    });
}
function formOTRobotSMSinicio3(player) {
    const formSistema = new ActionFormData()
        .title('text.title.OTRobotSMSinicioTitle')
        .body({ translate: "text.body1.OTRobotSMSinicioBody3", with: ['\n']})
        .button('text.button.OTRobotSMSinicioButton')

    formSistema.show(player).then((response) => {
        if(response.selection == 0){
            
        } else if(response.canceled){
            formOTRobotSMSinicio3(player);
            }
    });
}